package info.serpal.oriol.news

import android.support.v7.app.AppCompatActivity
import android.os.Bundle
import android.text.TextUtils
import android.util.Log
import android.view.View
import info.serpal.oriol.news.core.Navigator
import info.serpal.oriol.news.core.Toast
import info.serpal.oriol.news.data.remote.CommentRepository
import kotlinx.android.synthetic.main.activity_contact.*

class ContactActivity : AppCompatActivity() {

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_contact)
        comment_activity_toolbar.setNavigationOnClickListener {
            onBackPressed()
        }
        setSupportActionBar(comment_activity_toolbar)
        supportActionBar?.setDisplayHomeAsUpEnabled(true)

        comment_button.isEnabled = true
        comment_button.setOnClickListener { sendComment() }
    }

    private fun sendComment() {
        val nameStr = name.text.toString()
        val emailStr = email.text.toString()
        val commentStr = comment.text.toString()

        var cancel = false
        var focusView: View? = null

        if (TextUtils.isEmpty(nameStr)) {
            name.error = getString(R.string.error_name)
            focusView = name
            cancel = true
        }
        if (!isEmailValid(emailStr)) {
            email.error = getString(R.string.error_email)
            focusView = email
            cancel = true
        }
        if (TextUtils.isEmpty(commentStr)) {
            comment.error = getString(R.string.error_comment)
            focusView = comment
            cancel = true
        }
        if (cancel) {
            focusView?.requestFocus()
        } else {
            form_progress.visibility = View.VISIBLE
            comment_button.isEnabled = false

            val commentRepository = CommentRepository()
            val commentRequest = commentRepository.request(nameStr, emailStr, commentStr)
            val disposable = commentRequest.subscribe(
                { result ->
                    run {
                        Log.d("ContactActivity", "result12 $result")
                        form_progress.visibility = View.GONE
                        Toast.OK(contact_layout, R.string.comment_sent) { Navigator().navigateToMain(this) }
                    }
                },
                { error ->
                    run {
                        Log.d("ContactActivity", "result12 " + error.message)
                        form_progress.visibility = View.GONE
                        Toast.KO(contact_layout, R.string.comment_error_sent)
                    }
                }
            )
        }
    }

    private fun isEmailValid(email: String): Boolean {
        return !TextUtils.isEmpty(email) && android.util.Patterns.EMAIL_ADDRESS.matcher(email).matches()
    }
}
