package info.serpal.oriol.news

import android.app.SearchManager
import android.content.Context
import android.support.v7.app.AppCompatActivity
import android.os.Bundle
import android.support.v4.view.GravityCompat
import android.support.v7.app.ActionBar
import android.support.v7.widget.SearchView
import android.view.Menu
import android.view.MenuItem
import info.serpal.oriol.news.model.News
import info.serpal.oriol.news.core.Navigator
import info.serpal.oriol.news.dto.SectionFactory
import io.reactivex.disposables.Disposable
import kotlinx.android.synthetic.main.activity_main.*
import com.crashlytics.android.Crashlytics
import info.serpal.oriol.news.core.Toast
import info.serpal.oriol.news.data.domain.HomepageService
import info.serpal.oriol.news.model.HomePageList
import io.fabric.sdk.android.Fabric
import io.reactivex.Observable
import io.realm.Realm
import io.realm.RealmConfiguration


class MainActivity : AppCompatActivity() {

    private var disposable: Disposable? = null
    private val newsAdapter: NewsAdapter = NewsAdapter(this) {
        Navigator().navigateToPieceOfNews(this, it)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)
        setSupportActionBar(main_activity_toolbar)
        Fabric.with(this, Crashlytics())
        Realm.init(this)
        val realmConfiguration = RealmConfiguration.Builder()
            .deleteRealmIfMigrationNeeded()
            .name("my_db")
            .build()
        Realm.setDefaultConfiguration(realmConfiguration)

        setMenuButtonInActionBar()

        main_activity_refresh.isRefreshing = true
        val homepageService = HomepageService()
        printNews(homepageService.request())

        main_activity_refresh.setOnRefreshListener {
            printNews(homepageService.remoteRequest())
        }

        recyclerview_news.adapter = newsAdapter

        onLateralMenuClick()
    }

    private fun printNews(newsSelector: Observable<HomePageList>) {
        disposable = newsSelector.subscribe(
            { result ->
                run {
                    val myList: List<News> =
                        listOf(News.fromTitle(getString(R.string.noticias_generales))) +
                        result.newsList.subList(0, 3) +
                        listOf(News.fromTitle(getString(R.string.breves))) +
                        result.shortList +
                        listOf(News.fromTitle(getString(R.string.opinion))) +
                        result.opinionList
                    newsAdapter.setData(myList)
                    newsAdapter.notifyDataSetChanged()
                }
            },
            {
                Toast.KO(drawer_layout, R.string.no_internet)
                main_activity_refresh.isRefreshing = false
            },
            { main_activity_refresh.isRefreshing = false }
        )
    }

    private fun setMenuButtonInActionBar() {
        val actionbar: ActionBar? = supportActionBar
        actionbar?.apply {
            setDisplayHomeAsUpEnabled(true)
            setHomeAsUpIndicator(R.drawable.ic_menu)
        }
    }

    private fun onLateralMenuClick() {
        nav_view.setNavigationItemSelectedListener { menuItem ->
            menuItem.isChecked = true
            drawer_layout.closeDrawers()
            when (menuItem.itemId) {
                R.id.news_general -> {
                    Navigator().navigateToSection(this, SectionFactory.general())
                    true
                }
                R.id.short_news -> {
                    Navigator().navigateToSection(this, SectionFactory.short())
                    true
                }
                R.id.opinion_news -> {
                    Navigator().navigateToSection(this, SectionFactory.opinion())
                    true
                }
                R.id.what_is_serpal -> {
                    Navigator().navigateToInformation(this)
                    true
                }
                R.id.favorite_news -> {
                    Navigator().navigateToFavorite(this)
                    true
                }
                R.id.contact -> {
                    Navigator().navigateToContact(this)
                    true
                }
                else -> super.onOptionsItemSelected(menuItem)
            }

        }
    }

    override fun onBackPressed() {
        if (drawer_layout.isDrawerOpen(GravityCompat.START)) {
            drawer_layout.closeDrawer(GravityCompat.START)
        } else {
            super.onBackPressed()
        }
    }

    override fun onCreateOptionsMenu(menu: Menu): Boolean {
        menuInflater.inflate(R.menu.options_menu, menu)

        val searchManager = getSystemService(Context.SEARCH_SERVICE) as SearchManager
        (menu.findItem(R.id.search).actionView as SearchView).apply {
            setSearchableInfo(searchManager.getSearchableInfo(componentName))
            isFocusable = true
            isIconified = true
            clearFocus()
        }

        return true

    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            android.R.id.home -> {
                drawer_layout.openDrawer(GravityCompat.START)
                true
            }
            R.id.section_menu_refresh -> {
                main_activity_refresh.isRefreshing = true
                val homepageService = HomepageService()
                printNews(homepageService.remoteRequest())
                true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }

    override fun onPause() {
        super.onPause()
        disposable?.dispose()
    }
}
