package info.serpal.oriol.news

import android.content.Context
import android.support.v7.widget.RecyclerView
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import android.view.LayoutInflater
import com.squareup.picasso.Picasso
import info.serpal.oriol.news.model.News

class NewsAdapter(val context: Context, val action: (item: News) -> Unit) : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    private val VIEW_TYPE_NEWS = 0
    private val VIEW_TYPE_SECTION = 1

    private var newsDTOS: List<News> = emptyList()

    fun setData(newsDTOS: List<News>) {
        this.newsDTOS = newsDTOS
    }

    override fun getItemViewType(position: Int): Int {
        if (position % 4 == 0) {
            return VIEW_TYPE_SECTION
        }
        return VIEW_TYPE_NEWS
    }

    override fun onCreateViewHolder(viewGroup: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        if (viewType == VIEW_TYPE_NEWS) {
            val view = LayoutInflater.from(viewGroup.context).inflate(R.layout.news_item_list, viewGroup, false)
            return NewsViewHolder(view)
        }
        val view = LayoutInflater.from(viewGroup.context).inflate(R.layout.news_section_title, viewGroup, false)
        return SectionViewHolder(view)
    }

    override fun getItemCount(): Int = newsDTOS.size

    override fun onBindViewHolder(newsViewHolder: RecyclerView.ViewHolder, position: Int) {
        if (newsViewHolder is NewsViewHolder) {
            val title: String = if (newsDTOS[position].number != 0) {
                "(" + newsDTOS[position].number + ") " + newsDTOS[position].title
            } else {
                newsDTOS[position].title
            }
            newsViewHolder.newsTitle.text = title
            newsViewHolder.newsDescription.text = newsDTOS[position].description
            if (newsDTOS[position].image.url.isNotEmpty()) {
                newsViewHolder.newsPhoto.visibility = View.VISIBLE
                Picasso.with(this.context).load(newsDTOS[position].image.url).into(newsViewHolder.newsPhoto)
            } else {
                newsViewHolder.newsPhoto.visibility = View.GONE
            }
            newsViewHolder.itemView.setOnClickListener { action(newsDTOS[position]) }
        } else if (newsViewHolder is SectionViewHolder) {
            newsViewHolder.sectionTitle.text = newsDTOS[position].title
        }
    }

    class NewsViewHolder(view: View) : RecyclerView.ViewHolder(view)
    {
        var newsTitle: TextView = view.findViewById(R.id.news_title)
        var newsDescription: TextView = view.findViewById(R.id.news_description)
        var newsPhoto: ImageView = view.findViewById(R.id.news_photo)
    }

    class SectionViewHolder(view: View) : RecyclerView.ViewHolder(view)
    {
        var sectionTitle: TextView = view.findViewById(R.id.news_section_title)
    }
}
