package info.serpal.oriol.news

import android.content.Intent
import android.support.v7.app.AppCompatActivity
import android.os.Bundle
import android.support.v7.widget.ShareActionProvider
import android.view.Menu
import kotlinx.android.synthetic.main.activity_piece_of_news.*
import android.support.v4.view.MenuItemCompat
import android.view.MenuItem
import android.view.View
import com.squareup.picasso.Picasso
import info.serpal.oriol.news.model.News
import info.serpal.oriol.news.core.Dialog
import info.serpal.oriol.news.core.Navigator.Companion.NEWS_KEY
import info.serpal.oriol.news.data.repository.FavoriteRepository
import info.serpal.oriol.news.model.FavoriteNewsDB
import info.serpal.oriol.news.core.Toast

class PieceOfNewsActivity : AppCompatActivity() {
    private var mShareActionProvider: ShareActionProvider? = null

    private lateinit var favoriteNewsDB: FavoriteNewsDB
    private val newsDBRepository = FavoriteRepository()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_piece_of_news)
        setSupportActionBar(piece_of_news_toolbar)
        supportActionBar?.setDisplayHomeAsUpEnabled(true)

        piece_of_news_toolbar.setNavigationOnClickListener {
            onBackPressed()
        }

        val intent = intent
        if (intent.hasExtra(NEWS_KEY)) {
            val news: News = intent?.extras?.getParcelable(NEWS_KEY)!!
            piece_of_news_title.text = news.title
            if (news.cita.isNullOrEmpty()) {
                piece_of_news_cite.visibility = View.GONE
            } else {
                piece_of_news_cite.text = news.cita
            }
            piece_of_news_secondTitle.text = news.secondTitle
            piece_of_news_date.text = news.date
            if (news.autor.isNullOrEmpty()) {
                piece_of_news_author.visibility = View.GONE
            } else {
                piece_of_news_author.text = news.autor
            }
            piece_of_news_description.text = news.newsText
            piece_of_news_url.text = news.url
            if (news.image.url.isNotEmpty()) {
                Picasso.with(this).load(news.image.url).into(piece_of_news_photo)
            }

            favoriteNewsDB = FavoriteNewsDB.fromNews(news)
        }
    }

    override fun onCreateOptionsMenu(menu: Menu?): Boolean {
        menuInflater.inflate(R.menu.piece_of_news_menu, menu)
        createShareMenuItem(menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            R.id.action_favorite -> {
                val alert = Dialog.confirmation(this, R.string.saveFavorite) {
                    newsDBRepository.save(favoriteNewsDB)
                    Toast.OK(piece_of_news_layout, R.string.favorite_saved) {}
                }
                alert.show()
                true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }

    private fun createShareMenuItem(menu: Menu?) {
        val item = menu?.findItem(R.id.piece_of_news_share)
        mShareActionProvider = MenuItemCompat.getActionProvider(item) as ShareActionProvider
        val myShareIntent = Intent(Intent.ACTION_SEND)
        myShareIntent.type = "text/plain"
        myShareIntent.putExtra(Intent.EXTRA_TEXT, piece_of_news_url.text)
        mShareActionProvider?.setShareIntent(myShareIntent)
    }

    override fun onDestroy() {
        super.onDestroy()
        newsDBRepository.close()
    }
}
