package info.serpal.oriol.news

import android.app.SearchManager
import android.content.Context
import android.content.Intent
import android.support.v7.app.AppCompatActivity
import android.os.Bundle
import android.support.v7.widget.SearchView
import android.util.Log
import android.view.Menu
import android.view.View
import info.serpal.oriol.news.core.Navigator
import info.serpal.oriol.news.core.Toast
import info.serpal.oriol.news.data.remote.SearchRepository
import io.reactivex.disposables.Disposable
import kotlinx.android.synthetic.main.activity_search_results.*

class SearchResultsActivity : AppCompatActivity() {
    private var disposable: Disposable? = null

    private val newsAdapter: SectionAdapter = SectionAdapter(this) {
        Log.d("SectionActivity", "Clicked $it")
        Navigator().navigateToPieceOfNews(this, it)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_search_results)
        Log.d("SearchResultsActivity", "result intent $intent")

        setSupportActionBar(section_search_results_toolbar)
        supportActionBar?.setDisplayHomeAsUpEnabled(true)

        handleIntent(intent)
    }

    override fun onCreateOptionsMenu(menu: Menu): Boolean {
        menuInflater.inflate(R.menu.options_menu, menu)

        val searchManager = getSystemService(Context.SEARCH_SERVICE) as SearchManager
        (menu.findItem(R.id.search).actionView as SearchView).apply {
            setSearchableInfo(searchManager.getSearchableInfo(componentName))
            isFocusable = true
            isIconified = false
            clearFocus()
        }

        return true

    }

    override fun onNewIntent(intent: Intent) {
        handleIntent(intent)
    }

    private fun handleIntent(intent: Intent) {

        if (Intent.ACTION_SEARCH == intent.action) {
            val query = intent.getStringExtra(SearchManager.QUERY)

            recyclerview_search_news.setHasFixedSize(true)

            val searchRepository = SearchRepository()
            val newsSelector = searchRepository.request(query)
            search_activity_loading.visibility = View.VISIBLE
            no_results.visibility = View.GONE
            disposable = newsSelector.subscribe(
                { result ->
                    run {
                        if (result.newsList.isEmpty()) {
                            no_results.visibility = View.VISIBLE
                        } else {
                            newsAdapter.setData(result.newsList)
                            newsAdapter.notifyDataSetChanged()
                            no_results.visibility = View.GONE
                        }
                    }
                },
                {
                    Toast.KO(search_layout, R.string.no_internet)
                    search_activity_loading.visibility = View.GONE
                },
                { search_activity_loading.visibility = View.GONE }
            )
            recyclerview_search_news.adapter = newsAdapter
        }
    }

    override fun onPause() {
        super.onPause()
        disposable?.dispose()
    }

}
