package info.serpal.oriol.news

import android.support.v7.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.view.Menu
import android.view.MenuItem
import info.serpal.oriol.news.core.Navigator
import info.serpal.oriol.news.core.Navigator.Companion.SECTION_KEY
import info.serpal.oriol.news.core.Toast
import info.serpal.oriol.news.data.domain.SectionService
import info.serpal.oriol.news.dto.SectionDTO
import info.serpal.oriol.news.dto.SectionFactory
import info.serpal.oriol.news.model.NewsList
import io.reactivex.Observable
import io.reactivex.disposables.Disposable
import kotlinx.android.synthetic.main.activity_section.*

class SectionActivity : AppCompatActivity() {

    private var disposable: Disposable? = null
    private var section: String = SectionFactory.GENERAL
    private val newsAdapter: SectionAdapter = SectionAdapter(this) {
        Log.d("SectionActivity", "Clicked $it")
        Navigator().navigateToPieceOfNews(this, it)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_section)

        val intent = intent
        if (intent.hasExtra(SECTION_KEY)) {
            val sectionDTO: SectionDTO = intent?.extras?.getParcelable(SECTION_KEY)!!
            section_activity_toolbar.title = sectionDTO.title
            section = sectionDTO.api
        }
        section_activity_toolbar.setNavigationOnClickListener {
            onBackPressed()
        }
        setSupportActionBar(section_activity_toolbar)
        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        recyclerview_section_news.setHasFixedSize(true)

        section_refresh.isRefreshing = true
        val sectionService = SectionService()
        printNews(sectionService.request(section))

        section_refresh.setOnRefreshListener {
            printNews(sectionService.remoteRequest(section))
        }
        recyclerview_section_news.adapter = newsAdapter
    }

    override fun onCreateOptionsMenu(menu: Menu?): Boolean {
        menuInflater.inflate(R.menu.section_menu, menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        return when (item.itemId) {
            R.id.section_menu_refresh -> {
                section_refresh.isRefreshing = true
                val sectionService = SectionService()
                printNews(sectionService.remoteRequest(section))
                true
            }
            else -> super.onOptionsItemSelected(item)
        }
    }

    private fun printNews(newsRequest: Observable<NewsList>) {
        disposable = newsRequest.subscribe(
            { result ->
                run {
                    Log.d("SectionActivity", "${result.newsList} result12")
                    newsAdapter.setData(result.newsList)
                    newsAdapter.notifyDataSetChanged()
                }
            },
            {
                Toast.KO(section_layout, R.string.no_internet)
                section_refresh.isRefreshing = false
            },
            { section_refresh.isRefreshing = false }
        )
    }

    override fun onPause() {
        super.onPause()
        disposable?.dispose()
    }
}
