package info.serpal.oriol.news

import android.content.Context
import android.support.v7.widget.RecyclerView
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import android.view.LayoutInflater
import com.squareup.picasso.Picasso
import info.serpal.oriol.news.model.News

class SectionAdapter(
    val context: Context,
    val action: (i: News) -> Unit
) : RecyclerView.Adapter<SectionAdapter.SectionNewsViewHolder>() {

    private var news: List<News> = emptyList()

    fun setData(news: List<News>) {
        this.news = news
    }

    override fun onCreateViewHolder(viewGroup: ViewGroup, p1: Int): SectionNewsViewHolder {
        val view = LayoutInflater.from(viewGroup.context).inflate(R.layout.news_item_list, viewGroup, false)
        return SectionNewsViewHolder(view)
    }

    override fun getItemCount(): Int = news.size

    override fun onBindViewHolder(sectionNewsViewHolder: SectionNewsViewHolder, position: Int) {
        val title: String = if (news[position].number != 0) {
            "(" + news[position].number + ") " + news[position].title
        } else {
            news[position].title
        }
        sectionNewsViewHolder.newsTitle.text = title
        sectionNewsViewHolder.newsDescription.text = news[position].description
        if (news[position].image.url.isNotEmpty()) {
            sectionNewsViewHolder.newsPhoto.visibility = View.VISIBLE
            Picasso.with(this.context).load(news[position].image.url).into(sectionNewsViewHolder.newsPhoto)
        } else {
            sectionNewsViewHolder.newsPhoto.visibility = View.GONE
        }
        sectionNewsViewHolder.itemView.setOnClickListener { action(news[position]) }
    }

    class SectionNewsViewHolder(view: View) : RecyclerView.ViewHolder(view)
    {
        var newsTitle: TextView = view.findViewById(R.id.news_title)
        var newsDescription: TextView = view.findViewById(R.id.news_description)
        var newsPhoto: ImageView = view.findViewById(R.id.news_photo)

    }
}
