package info.serpal.oriol.news.api

import info.serpal.oriol.news.model.Comment
import info.serpal.oriol.news.model.HomePageList
import info.serpal.oriol.news.model.NewsList
import retrofit2.Retrofit
import retrofit2.adapter.rxjava2.RxJava2CallAdapterFactory
import retrofit2.converter.gson.GsonConverterFactory
import io.reactivex.Observable
import retrofit2.http.*

interface ApiService {

    @GET("noticias.json")
    fun generalNews(): Observable<NewsList>

    @GET("opinion.json")
    fun opinionNews(): Observable<NewsList>

    @GET("breves.json")
    fun shortNews(): Observable<NewsList>

    @GET("index.json")
    fun homepageNews(): Observable<HomePageList>

    @GET("search.json")
    fun searchNews(@Query("search") search: String): Observable<NewsList>

    @FormUrlEncoded
    @POST("comments")
    fun postComment(@Field("name") name: String, @Field("email") email: String,
                    @Field("comment") comment: String, @Field("token") token: String,
                    @Field("timestamp") timestamp: String): Observable<Comment>

    companion object {
        fun create(): ApiService {

            val retrofit = Retrofit.Builder()
                .addCallAdapterFactory(RxJava2CallAdapterFactory.create())
                .addConverterFactory(GsonConverterFactory.create())
                .baseUrl("https://serpal.info/")
                .build()

            return retrofit.create(ApiService::class.java)
        }
    }

}