package info.serpal.oriol.news.data.domain

import android.util.Log
import info.serpal.oriol.news.data.remote.HomepageRepository
import info.serpal.oriol.news.data.repository.NewsDBRepository
import info.serpal.oriol.news.dto.SectionFactory
import info.serpal.oriol.news.model.HomePageList
import io.reactivex.Observable

class HomepageService {
    private val sectionRepository: HomepageRepository = HomepageRepository()
    private val newsDBRepository = NewsDBRepository()

    fun request(): Observable<HomePageList> {
        val newsList = newsDBRepository.findTopBy(SectionFactory.GENERAL)
        val opinionList = newsDBRepository.findTopBy(SectionFactory.OPINION)
        val shortList = newsDBRepository.findTopBy(SectionFactory.SHORT)
        if (newsList.isNotEmpty() && opinionList.isNotEmpty() && shortList.isNotEmpty()) {
            Log.d("MainActivity", "result12 from memory")
            return Observable.fromArray(HomePageList(newsList, shortList, opinionList))
        }
        return remoteRequest()
    }

    fun remoteRequest(): Observable<HomePageList> {
        val newsRequest = sectionRepository.request()
        newsRequest.subscribe(
            { result ->
                run {
                    Log.d("MainActivity", "result12 from REMOTE")
                    if (result.newsList.isNotEmpty()) {
                        newsDBRepository.save(result.newsList, SectionFactory.GENERAL)
                        newsDBRepository.save(result.opinionList, SectionFactory.OPINION)
                        newsDBRepository.save(result.shortList, SectionFactory.SHORT)
                    }
                }
            },
            { error -> Log.d("SectionActivity", "result12 " + error.message) }
        ).dispose()
        newsDBRepository.close()
        return newsRequest
    }

}