package info.serpal.oriol.news.data.domain

import android.util.Log
import info.serpal.oriol.news.data.remote.SectionRepository
import info.serpal.oriol.news.data.repository.NewsDBRepository
import info.serpal.oriol.news.model.NewsList
import io.reactivex.Observable

class SectionService {
    private val sectionRepository: SectionRepository = SectionRepository()
    private val newsDBRepository = NewsDBRepository()

    fun request(section: String): Observable<NewsList> {
        Log.d("SectionActivity", "result12 section $section")
        val newsList = newsDBRepository.findAllBy(section)
        if (newsList.isNotEmpty()) {
            Log.d("SectionActivity", "result12 from memory")
            return Observable.fromArray(NewsList(newsList))
        }
        return remoteRequest(section)
    }

    fun remoteRequest(section: String): Observable<NewsList> {
        val newsRequest = sectionRepository.request(section)
        newsRequest.subscribe(
            { result ->
                run {
                    Log.d("SectionActivity", "result12 from REMOTE")
                    if (result.newsList.isNotEmpty()) {
                        newsDBRepository.save(result.newsList, section)
                    }
                }
            },
            { error -> Log.d("SectionActivity", "result12 " + error.message) }
        ).dispose()
        newsDBRepository.close()
        return newsRequest
    }

}