package info.serpal.oriol.news.data.repository

import info.serpal.oriol.news.data.repository.base.DBRepository
import info.serpal.oriol.news.model.News
import info.serpal.oriol.news.model.NewsDB
import io.realm.Sort
import io.realm.kotlin.where

class NewsDBRepository : DBRepository() {
    fun findTopBy(section: String): List<News> {
        val list = realm.where<NewsDB>()
            .equalTo("section", section)
            .sort("number", Sort.DESCENDING)
            .limit(3)
            .findAll()
        return list.map { newsDB: NewsDB -> NewsDB.toNews(newsDB)  }
    }

    fun findAllBy(section: String): List<News> {
        val list = realm.where<NewsDB>().equalTo("section", section).findAll()
        return list.map { newsDB: NewsDB -> NewsDB.toNews(newsDB)  }
    }

    fun save(newsList: List<News>, section: String) {
        val newsDBList = newsList.map { news: News -> NewsDB.fromNews(news, section) }

        realm.executeTransaction { realm ->
            realm.insertOrUpdate(newsDBList)
        }
    }
}